@@ -12,7 +12,7 @@ use parent 'Plack::Middleware';
 use HTTP::Status qw/ :constants /;
 use Time::HiRes 1.9764 qw/ clock_gettime CLOCK_REALTIME /;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -49,7 +49,7 @@ Plack::Middleware::TimeOverHTTP - time over HTTP middleware
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ on IP address. You will need to use additional middleware for that.
 =head1 SEE ALSO
 
 The "Time Over HTTPS specification" at
-L<http://phk.freebsd.dk/time/20151129.html>.
+L<http://phk.freebsd.dk/time/20151129/>.
 
 =head1 AUTHOR
 
